define(
//begin v1.x content
{
	"HKD_displayName": "港元",
	"CNY_displayName": "人民币",
	"JPY_displayName": "日元",
	"JPY_symbol": "JP¥",
	"USD_displayName": "美元",
	"CAD_symbol": "CA$",
	"GBP_displayName": "英镑",
	"CHF_displayName": "瑞士法郎",
	"CNY_symbol": "￥",
	"EUR_displayName": "欧元",
	"GBP_symbol": "£",
	"CAD_displayName": "加拿大元",
	"USD_symbol": "US$",
	"EUR_symbol": "€",
	"AUD_displayName": "澳大利亚元",
	"CHF_symbol": "CHF",
	"HKD_symbol": "HK$",
	"AUD_symbol": "AU$"
}
//end v1.x content
);